==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/bg/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Този раздел все още е празен!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Този раздел все още е празен!</b>Започнете, като публикувате нещо тук...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вие не сте член на този раздел и все още няма публично съдържание!</b>',
    '<strong>About</strong> the Space' => '<strong>За</strong> раздела',
    '<strong>About</strong> your membership' => '<strong>За</strong> вашето членство',
    '<strong>Confirm</strong> image deletion' => '<strong>Потвърди</strong> изтриването на изображението',
    '<strong>Invite</strong> members' => '<strong>Покани</strong> членове',
    '<strong>New</strong> member request' => 'Заявка за <strong>нов</strong> член',
    '<strong>New</strong> spaces' => '<strong>Нови</strong> раздели',
    '<strong>Request</strong> Membership' => '<strong>Заяви</strong> членство за раздел',
    '<strong>Space</strong> followers' => 'Последователи на <strong>раздела</strong>',
    '<strong>Space</strong> members' => 'Членове на <strong>раздела</strong>',
    '<strong>Space</strong> menu' => 'Меню на <strong>раздела</strong>',
    'About' => 'За',
    'Accept' => 'Приеми',
    'Accept Invite' => 'Приеми покана',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Моля, представете се накратко, за да станете одобрен член на този раздел.',
    'Add users without invitation' => 'Добави потребители без покана',
    'Admin' => 'Админ',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администратори',
    'Archived' => 'Архиварано',
    'As owner you cannot revoke your membership!' => 'Като собственик не можете да оттеглите членството си!',
    'Cancel' => 'Отказ',
    'Close' => 'Затвори',
    'Color' => 'Цвят',
    'Could not request membership!' => 'Не може да бъде поискано членство!',
    'Created At' => 'Създадено на',
    'Created By' => 'Създадено от',
    'Decline' => 'Откажи',
    'Decline Invite' => 'Откажи покана',
    'Default' => 'По подразбиране',
    'Default content visibility' => 'Видимост на съдържанието по подразбиране',
    'Delete' => 'Изтрий',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Наистина ли искате да изтриете изображението на потребителския си профил?',
    'Do you really want to delete your title image?' => 'Наистина ли искате да изтриете заглавното си изображение?',
    'Done' => 'Готово',
    'Email addresses' => 'Имейл адреси',
    'Everyone can enter' => 'Всеки може да се присъедини',
    'Follow' => 'Следвай',
    'Followers' => 'Последователи',
    'Following' => 'Следва',
    'Guests' => 'Гости',
    'Hide Members sidebar in the stream page.' => 'Скриване на страничната лента на членовете в страницата на потока.',
    'Homepage' => 'Начална страница',
    'Homepage (Guests)' => 'Начална страница (Гости)',
    'Invite' => 'Покани',
    'Invite and request' => 'Покани и заявки',
    'Invite by email' => 'Покани чрез имейл',
    'Invites' => 'Покани',
    'Join' => 'Присъедини се',
    'Join Policy' => 'Политика за присъединяване',
    'Last Visit' => 'Последно посещение',
    'Login' => 'Вход',
    'Max. 100 characters.' => 'Макс. 100 знака.',
    'Member since' => 'Член от',
    'Members' => 'Членове',
    'Moderator' => 'Модератор',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модератори',
    'My Space List' => 'Моят списък с раздели',
    'My space summary' => 'Резюме за моят раздел',
    'Name' => 'Име',
    'New user by e-mail (comma separated)' => 'Нов потребител по имейл (разделени със запетая)',
    'New user?' => 'Нов потребител?',
    'No results found!' => 'Няма намерени резултати!',
    'No spaces found.' => 'Няма намерени раздели.',
    'Only by invite' => 'Само при покана',
    'Originator User ID' => 'Идентификатор на потребителя на оригинатор',
    'Owner' => 'Собственик',
    'Owner:' => 'Собственик:',
    'Pending' => 'Изчакваща',
    'Pick users' => 'Избери потребители',
    'Posts' => 'Публикации',
    'Private' => 'Личен',
    'Private (Invisible)' => 'Лична зона (Невидима)',
    'Public' => 'Публичен',
    'Public (Members & Guests)' => 'Публичен (Членове и Гости)',
    'Public (Members only)' => 'Публичен (само Членове)',
    'Public (Registered users only)' => 'Публичен (само регистрирани потребители)',
    'Request Message' => 'Заявка за съобщение',
    'Role' => 'Роля',
    'See all' => 'Виж всички',
    'Select all registered users' => 'Избери всички регистрирани потребители',
    'Send' => 'Изпрати',
    'Settings' => 'Настройки',
    'Settings could not be saved!' => 'Настройките не могат да бъдат запазени!',
    'Show all' => 'Покажи всички',
    'Shown on About Page.' => 'Показано в "За" Страницата.',
    'Sorry, you are not allowed to leave this space!' => 'За съжаление нямате право да напускате този раздел!',
    'Sorting' => 'Подреждане',
    'Space' => 'Раздел',
    'Space Visibility' => 'Видимост на раздела',
    'Space directory' => 'Директория на раздела',
    'Space is invisible!' => 'Раздела не е видим!',
    'Spaces' => 'Раздели',
    'Status' => 'Статус',
    'Stream' => 'Поток',
    'Tags' => 'Етикети',
    'There is no pending invite!' => 'Няма чакащи покани!',
    'This action is only available for workspace members!' => 'Това действие е достъпно само за членовете на работния раздел!',
    'This user is already a member of this space.' => 'Този потребител вече е член на този раздел.',
    'This user is not a member of this space.' => 'Този потребител не е член на този раздел.',
    'To invite users to this space, please type their names below to find and pick them.' => 'За да поканите потребители в този раздел, моля, въведете имената им по-долу, за да ги намерите и изберете.',
    'Updated At' => 'Променено на',
    'Updated By' => 'Променено от',
    'Updated by' => 'Променено от',
    'User \'{username}\' is already a member of this space!' => 'Потребителят \'{username}\' вече е член на този раздел!',
    'User invitations have been added to the queue' => 'Поканите на потребителя са добавени към опашката',
    'User memberships have been added to the queue' => 'Потребителските членства са добавени към опашката',
    'User not found!' => 'Потребителят не е намерен!',
    'Users' => 'Потребители',
    'Users has been invited.' => 'Потребителите бяха поканени.',
    'Visibility' => 'Видимост',
    'Visible for all (members and guests)' => 'Видим за всички (членове и гости)',
    'You are not allowed to join this space!' => 'Нямате право да се присъединявате към този раздел!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Можете също така да поканите външни потребители, които не са регистрирани в момента. Просто добавете техните имейл адреси, разделени със запетая.',
    'You cannot create private visible spaces!' => 'Не можете да създавате частни видими раздели!',
    'You cannot create public visible spaces!' => 'Не можете да създавате публични видими раздели!',
    'You need to login to view contents of this space!' => 'Трябва да влезете, за да видите съдържанието на този раздел!',
    'Your Message' => 'Съобщение за приложение',
    'Your request was successfully submitted to the space administrators.' => 'Вашата заявка беше изпратена успешно до администраторите на раздела.',
    '{count} members' => '{count} членове',
    '{email} is not valid!' => '{email} е невалиден!',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'I want to become a member because...' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'Oldest first' => '',
    'Search...' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/space/messages/bg/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>Този раздел все още е празен!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Този раздел все още е празен!</b>Започнете, като публикувате нещо тук...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Вие не сте член на този раздел и все още няма публично съдържание!</b>',
    '<strong>About</strong> the Space' => '<strong>За</strong> раздела',
    '<strong>About</strong> your membership' => '<strong>За</strong> вашето членство',
    '<strong>Confirm</strong> image deletion' => '<strong>Потвърди</strong> изтриването на изображението',
    '<strong>Invite</strong> members' => '<strong>Покани</strong> членове',
    '<strong>New</strong> member request' => 'Заявка за <strong>нов</strong> член',
    '<strong>New</strong> spaces' => '<strong>Нови</strong> раздели',
    '<strong>Request</strong> Membership' => '<strong>Заяви</strong> членство за раздел',
    '<strong>Space</strong> followers' => 'Последователи на <strong>раздела</strong>',
    '<strong>Space</strong> members' => 'Членове на <strong>раздела</strong>',
    '<strong>Space</strong> menu' => 'Меню на <strong>раздела</strong>',
    'About' => 'За',
    'Accept' => 'Приеми',
    'Accept Invite' => 'Приеми покана',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Моля, представете се накратко, за да станете одобрен член на този раздел.',
    'Add users without invitation' => 'Добави потребители без покана',
    'Admin' => 'Админ',
    'Administrator:' => 'Администратор:',
    'Administrators' => 'Администратори',
    'Archived' => 'Архиварано',
    'As owner you cannot revoke your membership!' => 'Като собственик не можете да оттеглите членството си!',
    'Cancel' => 'Отказ',
    'Close' => 'Затвори',
    'Color' => 'Цвят',
    'Could not request membership!' => 'Не може да бъде поискано членство!',
    'Created At' => 'Създадено на',
    'Created By' => 'Създадено от',
    'Decline' => 'Откажи',
    'Decline Invite' => 'Откажи покана',
    'Default' => 'По подразбиране',
    'Default content visibility' => 'Видимост на съдържанието по подразбиране',
    'Delete' => 'Изтрий',
    'Description' => 'Описание',
    'Do you really want to delete your profile image?' => 'Наистина ли искате да изтриете изображението на потребителския си профил?',
    'Do you really want to delete your title image?' => 'Наистина ли искате да изтриете заглавното си изображение?',
    'Done' => 'Готово',
    'Email addresses' => 'Имейл адреси',
    'Everyone can enter' => 'Всеки може да се присъедини',
    'Follow' => 'Следвай',
    'Followers' => 'Последователи',
    'Following' => 'Следва',
    'Guests' => 'Гости',
    'Homepage' => 'Начална страница',
    'Invite' => 'Покани',
    'Invite and request' => 'Покани и заявки',
    'Invite by email' => 'Покани чрез имейл',
    'Invites' => 'Покани',
    'Join' => 'Присъедини се',
    'Join Policy' => 'Политика за присъединяване',
    'Last Visit' => 'Последно посещение',
    'Login' => 'Вход',
    'Max. 100 characters.' => 'Макс. 100 знака.',
    'Member since' => 'Член от',
    'Members' => 'Членове',
    'Moderator' => 'Модератор',
    'Moderator:' => 'Модератор:',
    'Moderators' => 'Модератори',
    'My Space List' => 'Моят списък с раздели',
    'My space summary' => 'Резюме за моят раздел',
    'Name' => 'Име',
    'New user by e-mail (comma separated)' => 'Нов потребител по имейл (разделени със запетая)',
    'New user?' => 'Нов потребител?',
    'No results found!' => 'Няма намерени резултати!',
    'No spaces found.' => 'Няма намерени раздели.',
    'Only by invite' => 'Само при покана',
    'Originator User ID' => 'Идентификатор на потребителя на оригинатор',
    'Owner' => 'Собственик',
    'Owner:' => 'Собственик:',
    'Pending' => 'Изчакваща',
    'Pick users' => 'Избери потребители',
    'Posts' => 'Публикации',
    'Private' => 'Личен',
    'Private (Invisible)' => 'Лична зона (Невидима)',
    'Public' => 'Публичен',
    'Public (Members & Guests)' => 'Публичен (Членове и Гости)',
    'Public (Members only)' => 'Публичен (само Членове)',
    'Public (Registered users only)' => 'Публичен (само регистрирани потребители)',
    'Request Message' => 'Заявка за съобщение',
    'Role' => 'Роля',
    'See all' => 'Виж всички',
    'Select all registered users' => 'Избери всички регистрирани потребители',
    'Send' => 'Изпрати',
    'Settings' => 'Настройки',
    'Settings could not be saved!' => 'Настройките не могат да бъдат запазени!',
    'Show all' => 'Покажи всички',
    'Shown on About Page.' => 'Показано в "За" Страницата.',
    'Sorry, you are not allowed to leave this space!' => 'За съжаление нямате право да напускате този раздел!',
    'Sorting' => 'Подреждане',
    'Space' => 'Раздел',
    'Space Visibility' => 'Видимост на раздела',
    'Space directory' => 'Директория на раздела',
    'Space is invisible!' => 'Раздела не е видим!',
    'Spaces' => 'Раздели',
    'Status' => 'Статус',
    'Stream' => 'Поток',
    'Tags' => 'Етикети',
    'There is no pending invite!' => 'Няма чакащи покани!',
    'This action is only available for workspace members!' => 'Това действие е достъпно само за членовете на работния раздел!',
    'This user is already a member of this space.' => 'Този потребител вече е член на този раздел.',
    'This user is not a member of this space.' => 'Този потребител не е член на този раздел.',
    'To invite users to this space, please type their names below to find and pick them.' => 'За да поканите потребители в този раздел, моля, въведете имената им по-долу, за да ги намерите и изберете.',
    'Updated At' => 'Променено на',
    'Updated By' => 'Променено от',
    'Updated by' => 'Променено от',
    'User \'{username}\' is already a member of this space!' => 'Потребителят \'{username}\' вече е член на този раздел!',
    'User invitations have been added to the queue' => 'Поканите на потребителя са добавени към опашката',
    'User memberships have been added to the queue' => 'Потребителските членства са добавени към опашката',
    'User not found!' => 'Потребителят не е намерен!',
    'Users' => 'Потребители',
    'Users has been invited.' => 'Потребителите бяха поканени.',
    'Visibility' => 'Видимост',
    'Visible for all (members and guests)' => 'Видим за всички (членове и гости)',
    'You are not allowed to join this space!' => 'Нямате право да се присъединявате към този раздел!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Можете също така да поканите външни потребители, които не са регистрирани в момента. Просто добавете техните имейл адреси, разделени със запетая.',
    'You cannot create private visible spaces!' => 'Не можете да създавате частни видими раздели!',
    'You cannot create public visible spaces!' => 'Не можете да създавате публични видими раздели!',
    'You need to login to view contents of this space!' => 'Трябва да влезете, за да видите съдържанието на този раздел!',
    'Your Message' => 'Съобщение за приложение',
    'Your request was successfully submitted to the space administrators.' => 'Вашата заявка беше изпратена успешно до администраторите на раздела.',
    '{count} members' => '{count} членове',
    '{email} is not valid!' => '{email} е невалиден!',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Guests)' => '',
    'I want to become a member because...' => '',
    'Member' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'Oldest first' => '',
    'Search...' => '',
    'Show as List' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];
